@@ -7,7 +7,8 @@ from django.urls import reverse
 from rest_framework import status
 from rest_framework.test import APITestCase
 
-from ..models import Like
+from likes.models import Like
+from likes.services import toggle
 
 User = get_user_model()
 
@@ -23,7 +24,11 @@ class BaseAPILikeTestCase(APITestCase):
             email='john@doe.com'
         )
         self.test_user = User.objects.create(username='test')
-        Like.like(self.user, self.content_type, self.test_user.pk)
+        self.like = toggle(
+            sender=self.user,
+            content_type=self.content_type,
+            object_id=self.test_user.pk
+        )[0]
 
     def tearDown(self):
         self.user.delete()
@@ -33,7 +38,7 @@ class BaseAPILikeTestCase(APITestCase):
 class LikeListAPIViewTestCase(BaseAPILikeTestCase):
     def setUp(self):
         super().setUp()
-        self.url = reverse('like-api:list-view')
+        self.url = reverse('likes-api:list')
 
     def test_list(self):
         self.client.login(username=self.username, password=self.password)
@@ -44,7 +49,7 @@ class LikeListAPIViewTestCase(BaseAPILikeTestCase):
 class UserCountOfLikesAPIViewTestCase(BaseAPILikeTestCase):
     def setUp(self):
         super().setUp()
-        self.url = reverse('like-api:count-view')
+        self.url = reverse('likes-api:count')
 
     def test_count(self):
         self.client.login(username=self.username, password=self.password)
@@ -55,7 +60,7 @@ class UserCountOfLikesAPIViewTestCase(BaseAPILikeTestCase):
 class LikeToggleViewTestCase(BaseAPILikeTestCase):
     def setUp(self):
         super().setUp()
-        self.url = reverse('like-api:toggle-view')
+        self.url = reverse('likes-api:toggle')
         self.valid_payload = {
             'id': self.test_user.pk,
             'content_type': self.content_type.pk,
@@ -68,7 +73,7 @@ class LikeToggleViewTestCase(BaseAPILikeTestCase):
 
         # test unlike
         with self.settings(LIKES_MODELS={'auth.User': {}}):
-            resp = self.client.post(
+            self.client.post(
                 self.url,
                 data=json.dumps(self.valid_payload),
                 content_type='application/json'
@@ -87,7 +92,7 @@ class LikeToggleViewTestCase(BaseAPILikeTestCase):
 class IsLikedAPIViewTestCase(BaseAPILikeTestCase):
     def setUp(self):
         super().setUp()
-        self.url = reverse('like-api:is-liked-view')
+        self.url = reverse('likes-api:is')
         self.valid_payload = {
             'ids': [self.test_user.pk],
             'content_type': self.content_type.pk,
@@ -100,4 +105,4 @@ class IsLikedAPIViewTestCase(BaseAPILikeTestCase):
             data=json.dumps(self.valid_payload),
             content_type='application/json'
         )
-        self.assertCountEqual(response.data.get('ids'), [self.test_user.pk])
+        self.assertCountEqual(response.data.get('ids'), [self.like.pk])
